==> birdtray_1.8.1+ds.orig.tar.xz: birdtray-1.8.1/src/translations/installer_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl_NL">
<context>
    <name>WindowsInstaller</name>
    <message>
        <source>__LANGUAGE_NAME__</source>
        <translatorcomment>This must be the name of one of the NSIS translation files at https://sourceforge.net/p/nsis/code/HEAD/tree/NSIS/trunk/Contrib/Language%20files/ without the file extension.</translatorcomment>
        <translation>Dutch</translation>
    </message>
    <message>
        <source>BirdtraySectionDescription</source>
        <translation>Een gratis systeemvakprogramma dat meldingen toont van Thunderbird.</translation>
    </message>
    <message>
        <source>WinIntegrationSectionName</source>
        <translation>Windows-integratie</translation>
    </message>
    <message>
        <source>WinIntegrationGroupDescription</source>
        <translation>Geef aan hoe u dit programma wilt integreren met Windows.</translation>
    </message>
    <message>
        <source>AutoRunSectionName</source>
        <translation>Automatisch opstarten</translation>
    </message>
    <message>
        <source>AutoRunDescription</source>
        <translation>Start ${PRODUCT_NAME} automatisch op na het aanmelden.</translation>
    </message>
    <message>
        <source>AutoCheckUpdateSectionName</source>
        <translation>Automatisch controleren op updates</translation>
    </message>
    <message>
        <source>AutoCheckUpdateDescription</source>
        <translation>Zoek tijdens het opstarten van ${PRODUCT_NAME} automatisch naar updates.</translation>
    </message>
    <message>
        <source>ProgramGroupSectionName</source>
        <translation>Programmagroep</translation>
    </message>
    <message>
        <source>ProgramGroupDescription</source>
        <translation>Maak een ${PRODUCT_NAME}-programmagroep aan onder Menu Start --&gt; Programma&apos;s.</translation>
    </message>
    <message>
        <source>DesktopEntrySectionName</source>
        <translation>Bureaubladpictogram</translation>
    </message>
    <message>
        <source>DesktopEntryDescription</source>
        <translation>Plaats een ${PRODUCT_NAME}-pictogram op het bureaublad.</translation>
    </message>
    <message>
        <source>StartMenuSectionName</source>
        <translation>Startmenu-item</translation>
    </message>
    <message>
        <source>StartMenuDescription</source>
        <translation>Plaats een ${PRODUCT_NAME}-pictogram in het Menu Start.</translation>
    </message>
    <message>
        <source>TranslationsSectionName</source>
        <translation>Vertalingen</translation>
    </message>
    <message>
        <source>TranslationsDescription</source>
        <translation>Kies vertalingen voor ${PRODUCT_NAME}. ${PRODUCT_NAME} kiest automatisch een taal op basis van uw systeemtaal.</translation>
    </message>
    <message>
        <source>UserSettingsSectionName</source>
        <translation>${PRODUCT_NAME}-gebruikersinstellingen</translation>
    </message>
    <message>
        <source>UserSettingsDescription</source>
        <translation>Uw persoonlijke ${PRODUCT_NAME}-instellingen en -configuratie.</translation>
    </message>
    <message>
        <source>LicenseStartMenuLinkName</source>
        <translation>Licentie-overeenkomst</translation>
    </message>
    <message>
        <source>FinishPageRunBirdtray</source>
        <translation>${PRODUCT_NAME} starten</translation>
    </message>
    <message>
        <source>UninstallerConfirmation</source>
        <translation>Klik op &apos;Deïnstalleren&apos; om te beginnen.</translation>
    </message>
    <message>
        <source>UninstallPreviousVersion</source>
        <translation>Bezig met deïnstalleren van de vorige versie van ${PRODUCT_NAME}</translation>
    </message>
    <message>
        <source>UninstallPreviousVersionError</source>
        <translation>Het deïnstalleren van de vorige versie van ${PRODUCT_NAME} is mislukt! Als u doorgaat, wordt ALLES verwijderd uit $3.</translation>
    </message>
    <message>
        <source>UninstallExecutionError</source>
        <translation>De deïnstallatie kan niet worden gestart.</translation>
    </message>
    <message>
        <source>StopBirdtray</source>
        <translation>${PRODUCT_NAME} is actief. Klik op &apos;Oké&apos; om ${PRODUCT_NAME} te stoppen en door te gaan met de installatie.</translation>
    </message>
    <message>
        <source>StoppingBirdtray</source>
        <translation>Bezig met afsluiten van ${EXE_NAME}</translation>
    </message>
    <message>
        <source>StopBirdtrayError</source>
        <translation>Het afsluiten van ${PRODUCT_NAME} is mislukt. Probeer het opnieuw of start ${PRODUCT_NAME} handmatig om door te gaan met de installatie.</translation>
    </message>
    <message>
        <source>StopBirdtrayUninstall</source>
        <translation>${PRODUCT_NAME} is actief. Klik op &apos;Oké&apos; om ${PRODUCT_NAME} te stoppen en door te gaan met de deïnstallatie.</translation>
    </message>
    <message>
        <source>StopBirdtrayUninstallError</source>
        <translation>Het afsluiten van ${PRODUCT_NAME} is mislukt. Probeer het opnieuw of start ${PRODUCT_NAME} handmatig om door te gaan met de deïnstallatie.</translation>
    </message>
    <message>
        <source>SetupAlreadyRunning</source>
        <translation>De installatiewizard van ${PRODUCT_NAME} is al actief.$\r$\nSluit alle processen af en klik op &apos;Opnieuw proberen&apos; om door te gaan of &apos;Annuleren&apos; om te stoppen.</translation>
    </message>
    <message>
        <source>UninstallAlreadyRunning</source>
        <translation>De deïnstallatiewizard van ${PRODUCT_NAME} is al actief.$\r$\nSluit alle processen af en klik op &apos;Opnieuw proberen&apos; om door te gaan of &apos;Annuleren&apos; om te stoppen.</translation>
    </message>
    <message>
        <source>BadInstallPath</source>
        <translation>Het installatiepad mag geen speciale tekens bevatten: $\r$\n${BAD_PATH_CHARS}.</translation>
    </message>
    <message>
        <source>InstallPathContainsPreviousVersion</source>
        <translation>Het installatiepad bevat een eerdere installatie van ${PRODUCT_NAME} - deze wordt vervangen.</translation>
    </message>
    <message>
        <source>InstallPathNotEmpty</source>
        <translation>Het installatiepad is niet leeg, maar het lijkt ook geen eerdere installatie van ${PRODUCT_NAME} te bevatten. De inhoud wordt overschreven.</translation>
    </message>
    <message>
        <source>CurrentUserOnly</source>
        <translation>$0 (alleen huidige gebruiker)</translation>
    </message>
    <message>
        <source>InstallFailed</source>
        <translation>${PRODUCT_NAME} ${VERSION} kan niet volledig worden geïnstalleerd.$\r$\n\Start Windows opnieuw op en start de installatiewizard opnieuw.</translation>
    </message>
    <message>
        <source>InstallFailedCauseUninstallerFailed</source>
        <translation>${PRODUCT_NAME} ${VERSION} kan niet volledig worden gedeïnstalleerd.$\r$\n\Start Windows opnieuw op en start de deïnstallatiewizard opnieuw.</translation>
    </message>
    <message>
        <source>UninstallFailed</source>
        <translation>${PRODUCT_NAME} ${VERSION} kan niet volledig worden gedeïnstalleerd.$\r$\n\Start Windows opnieuw op en start de deïnstallatiewizard opnieuw.</translation>
    </message>
    <message>
        <source>FileDeleteErrorDialog</source>
        <translation>Het volgende bestand kan niet worden verwijderd:$\r$\n$\r$\n$0$\r$\n$\r$\nKlik op &apos;Opnieuw proberen&apos; om het opnieuw te proberen, of$\r$\n&apos;Annuleren&apos; om te stoppen.</translation>
    </message>
    <message>
        <source>FileDeleteError</source>
        <translation>Het volgende bestand kan niet worden verwijderd: $0</translation>
    </message>
    <message>
        <source>Install64On32BitWarning</source>
        <translation>U staat op het punt om de 32-bitversie van ${PRODUCT_NAME} te installeren, maar uw Windows-installatie is 64-bit. Er is ook een 64-bitversie van ${PRODUCT_NAME} beschikbaar.</translation>
    </message>
    <message>
        <source>Install32On64BitError</source>
        <translation>Deze installatiewizard bevat een 64-bitversie van ${PRODUCT_NAME}. Uw computer draait een 32-bitversie van Windows, maar deze kan geen 64-bitprogramma&apos;s uitvoeren. Download the 32-bitinstallatiewizard van ${PRODUCT_NAME}.</translation>
    </message>
    <message>
        <source>UnsupportedWindowsVersionError</source>
        <translation>Dit programma vereist Windows ${MIN_WINDOWS_VER} of hoger.</translation>
    </message>
    <message>
        <source>UninstallerAborted</source>
        <translation>De deïnstallatiewizard van ${PRODUCT_NAME} is afgebroken. Probeer het later opnieuw.</translation>
    </message>
    <message>
        <source>SettingsLink</source>
        <translation>${PRODUCT_NAME}-instellingen</translation>
    </message>
    <message>
        <source>UninstallRestartAsUserQuestion</source>
        <translation>De deïnstallatie is gestart met administratorrechten, maar er is geen ${PRODUCT_NAME}-installatie aangetroffen op het administratoraccount. Wilt u de deïnstallatie opnieuw starten zonder administratorrechten?</translation>
    </message>
    <message>
        <source>OpenUrl</source>
        <translation>Bezig met openen van $0...</translation>
    </message>
    <message>
        <source>MissingVcRuntime</source>
        <translation>Visual C++ Runtime ${ARCH} ontbreekt.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Dialog</source>
        <translation>Het volgende vereiste onderdeel is niet aangetroffen op uw computer:$\r$\nVisual C++ Runtime ${ARCH}$\r$\nWilt u de installatiewizard van dit onderdeel downloaden?</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Retry</source>
        <translation>Draai, na het downloaden, de installatiewizard. Zodra de installatie is afgerond, kunt u op Oké klikken om de installatiestatus nogmaals te controleren.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Found</source>
        <translation>Het vereiste onderdeel is aangetroffen op uw computer.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_StillNotFound</source>
        <translation>Het vereiste onderdeel is nog steeds niet aangetroffen op uw computer. Zoek op internet naar Visual C++ ${ARCH}-downloads voor Visual Studio 2015 of nieuwer.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_UnableToRun</source>
        <translation>${PRODUCT_NAME} kan niet worden gestart.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_UnableToRunDialog</source>
        <translation>${PRODUCT_NAME} kan niet worden gestart omdat er een vereist onderdeel ontbreekt.</translation>
    </message>
    <message>
        <source>Lang_en</source>
        <translation>Engels</translation>
    </message>
    <message>
        <source>Lang_de</source>
        <translation>Duits</translation>
    </message>
    <message>
        <source>Lang_nl</source>
        <translation>Nederlands</translation>
    </message>
    <message>
        <source>Lang_it</source>
        <translation>Italiaans</translation>
    </message>
    <message>
        <source>Lang_ru</source>
        <translation>Russisch</translation>
    </message>
    <message>
        <source>Lang_pt</source>
        <translation>Portugees</translation>
    </message>
    <message>
        <source>Lang_es</source>
        <translation>Spaans</translation>
    </message>
</context>
</TS>

==> birdtray_1.9.0+ds.orig.tar.xz: birdtray-1.9.0/src/translations/installer_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl_NL">
<context>
    <name>WindowsInstaller</name>
    <message>
        <source>__LANGUAGE_NAME__</source>
        <translatorcomment>This must be the name of one of the NSIS translation files at https://sourceforge.net/p/nsis/code/HEAD/tree/NSIS/trunk/Contrib/Language%20files/ without the file extension.</translatorcomment>
        <translation>Dutch</translation>
    </message>
    <message>
        <source>BirdtraySectionDescription</source>
        <translation>Een gratis systeemvakprogramma dat meldingen toont van Thunderbird.</translation>
    </message>
    <message>
        <source>WinIntegrationSectionName</source>
        <translation>Windows-integratie</translation>
    </message>
    <message>
        <source>WinIntegrationGroupDescription</source>
        <translation>Geef aan hoe u dit programma wilt integreren met Windows.</translation>
    </message>
    <message>
        <source>AutoRunSectionName</source>
        <translation>Automatisch opstarten</translation>
    </message>
    <message>
        <source>AutoRunDescription</source>
        <translation>Start ${PRODUCT_NAME} automatisch op na het aanmelden.</translation>
    </message>
    <message>
        <source>AutoCheckUpdateSectionName</source>
        <translation>Automatisch controleren op updates</translation>
    </message>
    <message>
        <source>AutoCheckUpdateDescription</source>
        <translation>Zoek tijdens het opstarten van ${PRODUCT_NAME} automatisch naar updates.</translation>
    </message>
    <message>
        <source>ProgramGroupSectionName</source>
        <translation>Programmagroep</translation>
    </message>
    <message>
        <source>ProgramGroupDescription</source>
        <translation>Maak een ${PRODUCT_NAME}-programmagroep aan onder Menu Start --&gt; Programma&apos;s.</translation>
    </message>
    <message>
        <source>DesktopEntrySectionName</source>
        <translation>Bureaubladpictogram</translation>
    </message>
    <message>
        <source>DesktopEntryDescription</source>
        <translation>Plaats een ${PRODUCT_NAME}-pictogram op het bureaublad.</translation>
    </message>
    <message>
        <source>StartMenuSectionName</source>
        <translation>Startmenu-item</translation>
    </message>
    <message>
        <source>StartMenuDescription</source>
        <translation>Plaats een ${PRODUCT_NAME}-pictogram in het Menu Start.</translation>
    </message>
    <message>
        <source>TranslationsSectionName</source>
        <translation>Vertalingen</translation>
    </message>
    <message>
        <source>TranslationsDescription</source>
        <translation>Kies vertalingen voor ${PRODUCT_NAME}. ${PRODUCT_NAME} kiest automatisch een taal op basis van uw systeemtaal.</translation>
    </message>
    <message>
        <source>UserSettingsSectionName</source>
        <translation>${PRODUCT_NAME}-gebruikersinstellingen</translation>
    </message>
    <message>
        <source>UserSettingsDescription</source>
        <translation>Uw persoonlijke ${PRODUCT_NAME}-instellingen en -configuratie.</translation>
    </message>
    <message>
        <source>LicenseStartMenuLinkName</source>
        <translation>Licentie-overeenkomst</translation>
    </message>
    <message>
        <source>FinishPageRunBirdtray</source>
        <translation>${PRODUCT_NAME} starten</translation>
    </message>
    <message>
        <source>UninstallerConfirmation</source>
        <translation>Klik op &apos;Deïnstalleren&apos; om te beginnen.</translation>
    </message>
    <message>
        <source>UninstallPreviousVersion</source>
        <translation>Bezig met deïnstalleren van de vorige versie van ${PRODUCT_NAME}</translation>
    </message>
    <message>
        <source>UninstallPreviousVersionError</source>
        <translation>Het deïnstalleren van de vorige versie van ${PRODUCT_NAME} is mislukt! Als u doorgaat, wordt ALLES verwijderd uit $3.</translation>
    </message>
    <message>
        <source>UninstallExecutionError</source>
        <translation>De deïnstallatie kan niet worden gestart.</translation>
    </message>
    <message>
        <source>StopBirdtray</source>
        <translation>${PRODUCT_NAME} is actief. Klik op &apos;Oké&apos; om ${PRODUCT_NAME} te stoppen en door te gaan met de installatie.</translation>
    </message>
    <message>
        <source>StoppingBirdtray</source>
        <translation>Bezig met afsluiten van ${EXE_NAME}</translation>
    </message>
    <message>
        <source>StopBirdtrayError</source>
        <translation>Het afsluiten van ${PRODUCT_NAME} is mislukt. Probeer het opnieuw of start ${PRODUCT_NAME} handmatig om door te gaan met de installatie.</translation>
    </message>
    <message>
        <source>StopBirdtrayUninstall</source>
        <translation>${PRODUCT_NAME} is actief. Klik op &apos;Oké&apos; om ${PRODUCT_NAME} te stoppen en door te gaan met de deïnstallatie.</translation>
    </message>
    <message>
        <source>StopBirdtrayUninstallError</source>
        <translation>Het afsluiten van ${PRODUCT_NAME} is mislukt. Probeer het opnieuw of start ${PRODUCT_NAME} handmatig om door te gaan met de deïnstallatie.</translation>
    </message>
    <message>
        <source>SetupAlreadyRunning</source>
        <translation>De installatiewizard van ${PRODUCT_NAME} is al actief.$\r$\nSluit alle processen af en klik op &apos;Opnieuw proberen&apos; om door te gaan of &apos;Annuleren&apos; om te stoppen.</translation>
    </message>
    <message>
        <source>UninstallAlreadyRunning</source>
        <translation>De deïnstallatiewizard van ${PRODUCT_NAME} is al actief.$\r$\nSluit alle processen af en klik op &apos;Opnieuw proberen&apos; om door te gaan of &apos;Annuleren&apos; om te stoppen.</translation>
    </message>
    <message>
        <source>BadInstallPath</source>
        <translation>Het installatiepad mag geen speciale tekens bevatten: $\r$\n${BAD_PATH_CHARS}.</translation>
    </message>
    <message>
        <source>InstallPathContainsPreviousVersion</source>
        <translation>Het installatiepad bevat een eerdere installatie van ${PRODUCT_NAME} - deze wordt vervangen.</translation>
    </message>
    <message>
        <source>InstallPathNotEmpty</source>
        <translation>Het installatiepad is niet leeg, maar het lijkt ook geen eerdere installatie van ${PRODUCT_NAME} te bevatten. De inhoud wordt overschreven.</translation>
    </message>
    <message>
        <source>CurrentUserOnly</source>
        <translation>$0 (alleen huidige gebruiker)</translation>
    </message>
    <message>
        <source>InstallFailed</source>
        <translation>${PRODUCT_NAME} ${VERSION} kan niet volledig worden geïnstalleerd.$\r$\n\Start Windows opnieuw op en start de installatiewizard opnieuw.</translation>
    </message>
    <message>
        <source>InstallFailedCauseUninstallerFailed</source>
        <translation>${PRODUCT_NAME} ${VERSION} kan niet volledig worden gedeïnstalleerd.$\r$\n\Start Windows opnieuw op en start de deïnstallatiewizard opnieuw.</translation>
    </message>
    <message>
        <source>UninstallFailed</source>
        <translation>${PRODUCT_NAME} ${VERSION} kan niet volledig worden gedeïnstalleerd.$\r$\n\Start Windows opnieuw op en start de deïnstallatiewizard opnieuw.</translation>
    </message>
    <message>
        <source>FileDeleteErrorDialog</source>
        <translation>Het volgende bestand kan niet worden verwijderd:$\r$\n$\r$\n$0$\r$\n$\r$\nKlik op &apos;Opnieuw proberen&apos; om het opnieuw te proberen, of$\r$\n&apos;Annuleren&apos; om te stoppen.</translation>
    </message>
    <message>
        <source>FileDeleteError</source>
        <translation>Het volgende bestand kan niet worden verwijderd: $0</translation>
    </message>
    <message>
        <source>Install64On32BitWarning</source>
        <translation>U staat op het punt om de 32-bitversie van ${PRODUCT_NAME} te installeren, maar uw Windows-installatie is 64-bit. Er is ook een 64-bitversie van ${PRODUCT_NAME} beschikbaar.</translation>
    </message>
    <message>
        <source>Install32On64BitError</source>
        <translation>Deze installatiewizard bevat een 64-bitversie van ${PRODUCT_NAME}. Uw computer draait een 32-bitversie van Windows, maar deze kan geen 64-bitprogramma&apos;s uitvoeren. Download the 32-bitinstallatiewizard van ${PRODUCT_NAME}.</translation>
    </message>
    <message>
        <source>UnsupportedWindowsVersionError</source>
        <translation>Dit programma vereist Windows ${MIN_WINDOWS_VER} of hoger.</translation>
    </message>
    <message>
        <source>UninstallerAborted</source>
        <translation>De deïnstallatiewizard van ${PRODUCT_NAME} is afgebroken. Probeer het later opnieuw.</translation>
    </message>
    <message>
        <source>SettingsLink</source>
        <translation>${PRODUCT_NAME}-instellingen</translation>
    </message>
    <message>
        <source>UninstallRestartAsUserQuestion</source>
        <translation>De deïnstallatie is gestart met administratorrechten, maar er is geen ${PRODUCT_NAME}-installatie aangetroffen op het administratoraccount. Wilt u de deïnstallatie opnieuw starten zonder administratorrechten?</translation>
    </message>
    <message>
        <source>OpenUrl</source>
        <translation>Bezig met openen van $0...</translation>
    </message>
    <message>
        <source>MissingVcRuntime</source>
        <translation>Visual C++ Runtime ${ARCH} ontbreekt.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Dialog</source>
        <translation>Het volgende vereiste onderdeel is niet aangetroffen op uw computer:$\r$\nVisual C++ Runtime ${ARCH}$\r$\nWilt u de installatiewizard van dit onderdeel downloaden?</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Retry</source>
        <translation>Draai, na het downloaden, de installatiewizard. Zodra de installatie is afgerond, kunt u op Oké klikken om de installatiestatus nogmaals te controleren.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_Found</source>
        <translation>Het vereiste onderdeel is aangetroffen op uw computer.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_StillNotFound</source>
        <translation>Het vereiste onderdeel is nog steeds niet aangetroffen op uw computer. Zoek op internet naar Visual C++ ${ARCH}-downloads voor Visual Studio 2015 of nieuwer.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_UnableToRun</source>
        <translation>${PRODUCT_NAME} kan niet worden gestart.</translation>
    </message>
    <message>
        <source>MissingVcRuntime_UnableToRunDialog</source>
        <translation>${PRODUCT_NAME} kan niet worden gestart omdat er een vereist onderdeel ontbreekt.</translation>
    </message>
    <message>
        <source>Lang_en</source>
        <translation>Engels</translation>
    </message>
    <message>
        <source>Lang_de</source>
        <translation>Duits</translation>
    </message>
    <message>
        <source>Lang_nl</source>
        <translation>Nederlands</translation>
    </message>
    <message>
        <source>Lang_it</source>
        <translation>Italiaans</translation>
    </message>
    <message>
        <source>Lang_ru</source>
        <translation>Russisch</translation>
    </message>
    <message>
        <source>Lang_pt</source>
        <translation>Portugees</translation>
    </message>
    <message>
        <source>Lang_es</source>
        <translation>Spaans</translation>
    </message>
    <message>
        <source>Lang_sv</source>
        <translation>Zweeds</translation>
    </message>
    <message>
        <source>Lang_tr</source>
        <translation>Turks</translation>
    </message>
    <message>
        <source>Lang_pl</source>
        <translation>Pools</translation>
    </message>
</context>
</TS>
